==> neper-4.0.0.tgz: neper-4.0.0/src/neut/neut_mesh/neut_mesh_fscanf/neut_mesh_fscanf_msh/neut_mesh_fscanf_msh_.h <==
/* This file is part of the Neper software package. */
/* Copyright (C) 2003-2020, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#include<stdio.h>
#include<stdlib.h>
#include<math.h>
#include<string.h>

#include"ut.h"
#include"neut.h"

extern void neut_mesh_fscanf_msh_head (FILE *, int *, char **);
extern void neut_mesh_fscanf_msh_nodes (FILE *, int, char *, struct NODES *, int **);
extern void neut_mesh_fscanf_msh_nodes_head (FILE *, int *);
extern void neut_mesh_fscanf_msh_nodes_prop (FILE *, char *, struct NODES *, int *);
extern void neut_mesh_fscanf_msh_nodes_foot (FILE  *);


extern void neut_mesh_fscanf_msh_elts (FILE * file, char *mode, int *node_nbs,
    struct MESH *pMesh0D, struct MESH *pMesh1D, struct
    MESH *pMesh2D, struct MESH *pMesh3D, struct MESH *pMeshCo, struct MESH **ppMesh);
extern int neut_mesh_fscanf_msh_elts_dim (FILE *, char *, struct MESH *, int *, int, int);
extern void neut_mesh_fscanf_msh_elts_foot (FILE *);
extern void neut_mesh_fscanf_msh_elts_dim_prop (FILE *, char *, struct MESH *, int **, int);

extern void neut_mesh_fscanf_msh_periodicity (FILE *file, struct NODES *pNodes);

extern void neut_mesh_fscanf_msh_physical (FILE *file, struct MESH *pMesh0D,
                               struct MESH *pMesh1D, struct MESH *pMesh2D,
                               struct MESH *pMesh3D);

extern void neut_mesh_fscanf_msh_orientations (FILE *file, char *entity, struct MESH *pMesh);
extern void neut_mesh_fscanf_msh_groups (FILE *file, struct MESH *pMesh);
extern void neut_mesh_fscanf_msh_nsets (FILE *file);
extern void neut_mesh_fscanf_msh_fasets (FILE *file, struct MESH *pMesh);
extern void neut_mesh_fscanf_msh_nodeparts (FILE *file, struct NODES *pNodes);

==> neper-4.0.2.tgz: neper-4.0.2/src/neut/neut_mesh/neut_mesh_fscanf/neut_mesh_fscanf_msh/neut_mesh_fscanf_msh_.h <==
/* This file is part of the Neper software package. */
/* Copyright (C) 2003-2020, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#include<stdio.h>
#include<stdlib.h>
#include<math.h>
#include<string.h>

#include"ut.h"
#include"neut.h"

extern void neut_mesh_fscanf_msh_head (FILE *, char **);
extern void neut_mesh_fscanf_msh_nodes (FILE *, char *, struct NODES *, int **);
extern void neut_mesh_fscanf_msh_nodes_head (FILE *, int *);
extern void neut_mesh_fscanf_msh_nodes_prop (FILE *, char *, struct NODES *, int *);
extern void neut_mesh_fscanf_msh_nodes_foot (FILE  *);


extern void neut_mesh_fscanf_msh_elts (FILE * file, char *mode, int *node_nbs,
    struct MESH *pMesh0D, struct MESH *pMesh1D, struct
    MESH *pMesh2D, struct MESH *pMesh3D, struct MESH *pMeshCo, struct MESH **ppMesh);
extern int neut_mesh_fscanf_msh_elts_dim (FILE *, char *, struct MESH *, int *, int, int);
extern void neut_mesh_fscanf_msh_elts_foot (FILE *);
extern void neut_mesh_fscanf_msh_elts_dim_prop (FILE *, char *, struct MESH *, int **, int);

extern void neut_mesh_fscanf_msh_periodicity (FILE *file, struct NODES *pNodes);

extern void neut_mesh_fscanf_msh_physical (FILE *file, struct MESH *pMesh0D,
                               struct MESH *pMesh1D, struct MESH *pMesh2D,
                               struct MESH *pMesh3D);

extern void neut_mesh_fscanf_msh_orientations (FILE *file, char *entity, struct MESH *pMesh);
extern void neut_mesh_fscanf_msh_groups (FILE *file, struct MESH *pMesh);
extern void neut_mesh_fscanf_msh_nsets (FILE *file);
extern void neut_mesh_fscanf_msh_fasets (FILE *file, struct MESH *pMesh);
extern void neut_mesh_fscanf_msh_nodeparts (FILE *file, struct NODES *pNodes);
